# Background.py

# Importion of modules.

import pygame

# Importion of own modules.
import helpers

# Initialize pygame
pygame.init()

class Background( pygame.sprite.Sprite ):
	"""
	The background that will scroll to the left during the game.
	We need at least two images, so it moves without interruption.
	"""

	image_ = None

	def __init__( self, top_left_pos ):
		"""

		This method initializes a single background object.

		Parameters
			top_left_pos	Integer array [ top, left ]
				Defines the topleft position of the background (where to display it).
		"""
		pygame.sprite.Sprite.__init__( self )

		# Store the passed parameters.
		self.top_left_pos = top_left_pos
		
		# When to create an additional background image ?
		self.create_additional_bg_at = 801


		# Load the image for the background.
		# These two lines prevent Pygame from loading the same image twice.  This leads to less memory usage.
		if Background.image_ == None:
			Background.image_ = helpers.load_image( "Background.png" )

		# Now load the image.
		self.image = Background.image_

		# Get the rect.
		self.rect = self.image.get_rect()

		# And position it.
		self.rect.topleft = self.top_left_pos


	def update( self ):
		"""
		This method updates the background.  It moves the background to the left each single frame.
		Also, this method checks if a background is not visible anymore, and whether a background has left the right border of the screen.
		"""

		# Move the background to the left.
		self.rect.move_ip( -3, 0 )

		# Has our background image disappeared on the left ?
		if self.rect.right <= 0:
			# Remove it.
			self.kill()

		# Otherwise, has our background image left the right border of the screen ?
		if self.rect.right == self.create_additional_bg_at:
			# Let us immediately create a new background.
			return True


		return False
